# Microsoft Academic Graph

**WARNING: MAG will be decommissioned at the end of 2021. See [announcement](https://www.microsoft.com/en-us/research/project/academic/articles/microsoft-academic-to-expand-horizons-with-community-driven-approach).** 

“Microsoft Academic (academic.microsoft.com) is a project exploring how to assist humans
conducting scientific research.” Semantics and AI learning are used to process documents
discovered by a web crawler and extract scholarly entities and their relationships to form
a knowledge base. The resulting Microsoft Academic Graph (MAG) is a “heterogeneous graph
containing scientific publication records, citation relationships between those publications,
as well as authors, institutions, journals, conferences, and fields of study.”
-- [MAG website](https://academic.microsoft.com/home).

"The Microsoft Academic Graph is a heterogeneous graph containing scientific publication 
records, citation relationships between those publications, as well as authors, institutions, 
journals, conferences, and fields of study.”
The dataset is provided as a set of related tables of data
. _- source: [MAG](https://www.microsoft.com/en-us/research/project/microsoft-academic-graph/
)_ 
and [data details](https://docs.microsoft.com/en-us/academic-services/graph/reference-data-schema
)

## Latest schema
### Affiliations
``` eval_rst
.. csv-table::
   :file: ../schemas/MagAffiliations_latest.csv
   :width: 100%
   :header-rows: 1
```
### AuthorExtendedAttributes
``` eval_rst
.. csv-table::
   :file: ../schemas/MagAuthorExtendedAttributes_latest.csv
   :width: 100%
   :header-rows: 1
```
### Authors
``` eval_rst
.. csv-table::
   :file: ../schemas/MagAuthors_latest.csv
   :width: 100%
   :header-rows: 1
```
### ConferenceInstances
``` eval_rst
.. csv-table::
   :file: ../schemas/MagConferenceInstances_latest.csv
   :width: 100%
   :header-rows: 1
```
### ConferenceSeries
``` eval_rst
.. csv-table::
   :file: ../schemas/MagConferenceSeries_latest.csv
   :width: 100%
   :header-rows: 1
```
### EntityRelatedEntites
``` eval_rst
.. csv-table::
   :file: ../schemas/MagEntityRelatedEntities_latest.csv
   :width: 100%
   :header-rows: 1
```

### FieldOfStudyChildren
``` eval_rst
.. csv-table::
   :file: ../schemas/MagFieldOfStudyChildren_latest.csv
   :width: 100%
   :header-rows: 1
```
### FieldOfStudyExtendedAttributes
``` eval_rst
.. csv-table::
   :file: ../schemas/MagFieldOfStudyExtendedAttributes_latest.csv
   :width: 100%
   :header-rows: 1
```
### FieldsOfStudy
``` eval_rst
.. csv-table::
   :file: ../schemas/MagFieldsOfStudy_latest.csv
   :width: 100%
   :header-rows: 1
```
### Journals
``` eval_rst
.. csv-table::
   :file: ../schemas/MagJournals_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperAbstractsInvertedIndex
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperAbstractsInvertedIndex_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperAuthorAffiliations
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperAuthorAffiliations_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperCitationContexts
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperCitationContexts_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperExtendedAttributes
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperExtendedAttributes_latest.csv
   :width: 100%
   :header-rows: 1
```

### PaperFieldsOfStudy
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperFieldsOfStudy_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperLanguages
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperLanguages_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperMeSH
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperMeSH_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperRecommendations
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperRecommendations_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperReferences
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperReferences_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperResources
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperResources_latest.csv
   :width: 100%
   :header-rows: 1
```
### Papers
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPapers_latest.csv
   :width: 100%
   :header-rows: 1
```
### PaperUrls
``` eval_rst
.. csv-table::
   :file: ../schemas/MagPaperUrls_latest.csv
   :width: 100%
   :header-rows: 1
```
### RelatedFieldOfStudy
``` eval_rst
.. csv-table::
   :file: ../schemas/MagRelatedFieldOfStudy_latest.csv
   :width: 100%
   :header-rows: 1